#
# spec file for package tuigreet
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tuigreet
Version:        0.9.1
Release:        1.3
Summary:        Graphical console greeter for greetd
License:        GPL-3.0-only
Group:          System/Management
URL:            https://github.com/apognu/tuigreet
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  cargo-packaging
Recommends:     greetd

%description
Graphical console UI greeter for greetd (using tui-rs)

%prep
%autosetup -p1 -a1

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Wed Jun  5 2024 Joshua Smith <smolsheep@opensuse.org>
- Fix description-shorter-than-summary rpmlint warning
- Update to 0.9.1
  * Fixed display issue where remembered session would display
    command instead of session name
  * Fixed issue with greetd IPC when no session is selected
  * Automatically select first session in list
* Tue May  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Enable tests
- Remove tuigreet-version.patch (Fixed upstream)
- Service to use manual instead of deprecated disabled
- Remove deprecated cargo_config (now part of vendor)
- Update to 0.9.0
  * Added rebinding of F-key actions.
  * Added more customization options and coloring support.
  * Added support for using NSS to retrieve users instead of
    /etc/passwd.
  * Better handling of rendering/event loop.
  * Support for X11 sessions specificities (environment variables,
    wrappers, etc.).
  * Better management of non-ASCII strings.
  * Better handling of smaller screens.
  * Overall better terminal management to clear screen on startup,
    exit and error conditions.
  * Various bugfixes.
  * Various locale updates.
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patch
* Wed Nov 16 2022 Denys Kondratenko <stdden@opensuse.org>
- Update to 0.8.0
  * Remember last successfully opened session per user
  * Suppress power command output
  * Allow customization of time format
  * Added a user selection list from a defined UID range
  * Miscellaneous UX improvements
  * Locales improvements
- add tuigreet-version.patch to fix incorrect 0.7.3 version
* Thu Aug  4 2022 William Brown <william.brown@suse.com>
- bsc#1182059 - CVE-2021-21299 - hyper request smuggling
* Thu May 26 2022 William Brown <william.brown@suse.com>
- Update vendored dependencies
* Mon Mar 14 2022 William Brown <william.brown@suse.com>
- Update to resolve bsc#1196972 CVE-2022-24713 - Regex DOS
* Fri Jan  7 2022 William Brown <william.brown@suse.com>
- resolve bsc#1194119 (CVE-2021-45710)
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Mon Nov  1 2021 Denys Kondratenko <stdden@opensuse.org>
- Update to 0.7.1
  * Upgraded greetd_ipc to 0.8.0.
  * Used async throughout tuigreet to prevent blocking the UI.
  * Better handle different kinds of PAM prompts (such as fingerprint
    scanner prompts).
  * Allow customizing power commands to shut down and reboot the machine.
  * Miscellaneous UI improvements and typo fixes.
  * Added Polish and Catalan translations.
  * Updated man page.
- tuigreet version 0.7.0
  * Upgraded greetd_ipc to 0.8.0.
  * Used async throughout tuigreet to prevent blocking the UI.
  * Better handle different kinds of PAM prompts (such as fingerprint
    scanner prompts).
  * Allow customizing power commands to shut down and reboot the machine.
  * Miscellaneous UI improvements and typo fixes.
  * Added Polish and Catalan translations.
- tuigreet version 0.6.1
  * manpage was added.
- tuigreet version 0.6.0
  * Added option to remember last selected session between runs.
  * Add customization of the password redaction character instead of *.
  * Added translations in Italian and Portugese.
- tuigreet version 0.5.0.
  * tuigreet used to terminate on authentication failure, which would
    pose security issues if greetd was configured to restart
    automatically with an `initial_session` set. Now, tuigreet loops on
    failure and keeps running (#24).
  * Following the previous item, all manual means of exiting tuigreet
    have been removed (such as hitting the ESC key).
  * Added localization of the user interface, with initial translations
    in English, French and German (thanks to @brodi1 for the German
    translation).
- tuigreet version 0.4.0
  * Add a space at the end of prompts if missing.
  * Added option to add global padding to the terminal.
  * Added menu to shut down and reboot the machine.
  * Fixed issue with container padding and greeting message.
- tuigreet version 0.3.1.
  * Fixed issue where popup menus would put the UI into an unrecoverable
    state
  * Fixed issue where closing a popup would not return to the correct mode
  * Fixed issue with the time format
  * Added options to provide custom directories to look for sessions
    desktop files
- tuigreet version 0.3.0.
  * Fixed issue where popup menus would put the UI into an unrecoverable
    state
  * Fixed issue with the time format
  * Added options to provide custom directories to look for sessions
    desktop files
* Tue Sep 28 2021 William Brown <william.brown@suse.com>
- Replace rust-packaging with cargo-packaging
* Mon Sep  7 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Initial package tuigreet 0.2.0
